using System;
using System.Linq;
using System.Threading.Tasks;
using AutoFixture;
using Couchbase.Core;
using Xunit;

namespace CouchbaseTests
{
    public class ExpiryTests
    {
        private readonly IBucket _bucket;
        private readonly Fixture _fixture;

        public ExpiryTests()
        {
            _bucket = CouchbaseFactory.InitializeBucket();
            _fixture = new Fixture();
        }

        [Fact]
        public async Task Expiry_ShouldBeSetTo90Days()
        {
            var doc = _fixture.Create<Document>();

            var upsertResult = await _bucket.UpsertAsync(doc.Identifier.ToString(), doc);

            var expiration = await GetExpirationOfDocument(doc.Identifier);

            Assert.True(expiration == 0);

            var mutation = _bucket.MutateIn<Document>(doc.Identifier.ToString())
                .Upsert(nameof(doc.MovedToAvailableOn), DateTime.UtcNow)
                .ArrayAppend(nameof(doc.Commands), new object())
                .WithExpiry(TimeSpan.FromDays(90))
                .WithCas(upsertResult.Cas);

            var result = await mutation.ExecuteAsync();

            var newExpiration = await GetExpirationOfDocument(doc.Identifier);

            Assert.False(newExpiration == 0);
        }

        public async Task<ulong> GetExpirationOfDocument(Guid identifier)
        {
            var query = $"SELECT meta().expiration FROM `bucket` AS f WHERE f.Identifier = '{identifier}'";
            var result = await _bucket.QueryAsync<dynamic>(query);
            var expiration = result.Rows.FirstOrDefault()?.expiration;
            return expiration;
        }
    }
}
