#!/bin/bash
# configure-node.sh

# Enables job control
set -m

# Enables error propagation
set -e

/entrypoint.sh couchbase-server &

# Check if couchbase server is up
check_db() {
  curl --silent http://127.0.0.1:8091/pools > /dev/null
  echo $?
}

# Variable used in echo
i=1

# Wait until it's ready
until [[ $(check_db) = 0 ]]; do
  >&2 echo "Waiting for Couchbase Server to be available ..."
  sleep 1
done

if couchbase-cli server-list -c 127.0.0.1 -u $COUCH_DB_USERNAME -p $COUCH_DB_PASSWORD; then
  >&2 echo "Cluster already initialized..."; 
else 
  # Setup index and memory quota
  >&2 echo "Init cluster ........."
  couchbase-cli cluster-init -c 127.0.0.1 --cluster-username $COUCH_DB_USERNAME --cluster-password $COUCH_DB_PASSWORD \
    --cluster-name localdb --cluster-ramsize 1024 --cluster-index-ramsize 256 --services data,index,query \
    --index-storage-setting default;
fi;

#If no buckets exist, create
bucketResponse=$(couchbase-cli bucket-list -c 127.0.0.1 -u $COUCH_DB_USERNAME -p $COUCH_DB_PASSWORD)
if [[ -n $bucketResponse ]]; then 
  >&2 echo "Bucket already initialized..."
  sleep 5;
else
  # Create the buckets
  >&2 echo "Create buckets ........."
  couchbase-cli bucket-create -c 127.0.0.1 --username $COUCH_DB_USERNAME --password $COUCH_DB_PASSWORD --bucket-type couchbase --bucket-ramsize 250 --bucket $PRIMARYBUCKET --wait
fi;

>&2 echo "Finished initializing Couchbase"

fg 1